==> haskell-quickcheck-text-0.1.2.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-FWu4QsAULEAfnXceIGJCk
key:                  quickcheck-text-0.1.2.1-FWu4QsAULEAfnXceIGJCk
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  f26ebfbe6fee79a413426c92979603ee
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/quickcheck-text-0.1.2.1
hs-libraries:         HSquickcheck-text-0.1.2.1-FWu4QsAULEAfnXceIGJCk
depends:
    QuickCheck-2.14.2-8squlTcK6MZAcxqLTZHpKw base-4.15.1.0
    binary-0.8.8.0 bytestring-0.10.12.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-text-0.1.2.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-1uPw9JyNsg99sJYkDU99FD
key:                  quickcheck-text-0.1.2.1-1uPw9JyNsg99sJYkDU99FD
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  7aff0a51de701fbe5e1da21a6bf9b7bb
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/quickcheck-text-0.1.2.1
hs-libraries:         HSquickcheck-text-0.1.2.1-1uPw9JyNsg99sJYkDU99FD
depends:
    QuickCheck-2.14.2-1ypjvWj62Tv8anPe2Haych base-4.15.1.0
    binary-0.8.8.0 bytestring-0.10.12.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
